pub enum IntegrationError {
NonFiniteState {
t: f64,
},
StepSizeTooSmall {
t: f64,
dt: f64,
},
}Expand description
Reason the integration was stopped by the integrator itself.
Variants
NonFiniteState
A NaN or Inf was detected in the state after a step.
StepSizeTooSmall
Step size became smaller than minimum threshold.